@@ -27,9 +27,11 @@
 #include <QMap>
 #include <QHash>
 #include <QReadWriteLock>
+#include <QExplicitlySharedDataPointer>
+#include <QObject>
 
 //qgis includes
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "qgsunittypes.h"
 #include "qgsrectangle.h"
 #include "qgssqliteutils.h"
@@ -191,6 +193,7 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
     Q_GADGET
 
     Q_PROPERTY( QgsUnitTypes::DistanceUnit mapUnits READ mapUnits )
+    Q_PROPERTY( bool isGeographic READ isGeographic )
 
   public:
 
@@ -207,6 +210,8 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
 
     ~QgsCoordinateReferenceSystem();
 
+    // TODO QGIS 4: remove "POSTGIS" and "INTERNAL", allow PROJ4 without the prefix
+
     /**
      * Constructs a CRS object from a string definition using createFromString()
      *
@@ -220,16 +225,18 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      * If no prefix is specified, WKT definition is assumed.
      * \param definition A String containing a coordinate reference system definition.
      * \see createFromString()
-     */ // TODO QGIS 3: remove "POSTGIS" and "INTERNAL", allow PROJ4 without the prefix
+     */
     explicit QgsCoordinateReferenceSystem( const QString &definition );
 
+    // TODO QGIS 4: remove type and always use EPSG code
+
     /**
      * Constructor a CRS object using a PostGIS SRID, an EPSG code or an internal QGIS CRS ID.
      * \note We encourage you to use EPSG code, WKT or Proj4 to describe CRS's in your code
      * wherever possible. Internal QGIS CRS IDs are not guaranteed to be permanent / involatile.
      * \param id The ID valid for the chosen CRS ID type
      * \param type One of the types described in CrsType
-     */ // TODO QGIS 3: remove type and always use EPSG code
+     */
     explicit QgsCoordinateReferenceSystem( long id, CrsType type = PostgisCrsId );
 
     //! Copy constructor
@@ -302,14 +309,18 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
 
     // Misc helper functions -----------------------
 
+    // TODO QGIS 4: remove type and always use EPSG code, rename to createFromEpsg
+
     /**
      * Sets this CRS by lookup of the given ID in the CRS database.
      * \returns True on success else false
      * \note We encourage you to use EPSG code, WKT or Proj4 to describe CRS's in your code
      * wherever possible. Internal QGIS CRS IDs are not guaranteed to be permanent / involatile.
-     */     // TODO QGIS 3: remove type and always use EPSG code, rename to createFromEpsg
+     */
     bool createFromId( long id, CrsType type = PostgisCrsId );
 
+    // TODO QGIS 4: remove "QGIS" and "CUSTOM", only support "USER" (also returned by authid())
+
     /**
      * Sets this CRS to the given OGC WMS-format Coordinate Reference Systems.
      *
@@ -319,14 +330,16 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      * \returns True on success else false
      * \note this method uses an internal cache. Call invalidateCache() to clear the cache.
      * \see fromOgcWmsCrs()
-     */     // TODO QGIS 3: remove "QGIS" and "CUSTOM", only support "USER" (also returned by authid())
+     */
     bool createFromOgcWmsCrs( const QString &crs );
 
+    // TODO QGIS 4: remove unless really necessary - let's use EPSG codes instead
+
     /**
      * Sets this CRS by lookup of the given PostGIS SRID in the CRS database.
      * \param srid The PostGIS SRID for the desired spatial reference system.
      * \returns True on success else false
-     */     // TODO QGIS 3: remove unless really necessary - let's use EPSG codes instead
+     */
     bool createFromSrid( long srid );
 
     /**
@@ -441,13 +454,15 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      */
     void validate();
 
+    // TODO QGIS 4: seems completely obsolete now (only compares proj4 - already done in createFromProj4)
+
     /**
      * Walks the CRS databases (both system and user database) trying to match
      *  stored PROJ string to a database entry in order to fill in further
      *  pieces of information about CRS.
      *  \note The ellipsoid and projection acronyms must be set as well as the proj4string!
      *  \returns long the SrsId of the matched CRS, zero if no match was found
-     */    // TODO QGIS 3: seems completely obsolete now (only compares proj4 - already done in createFromProj4)
+     */
     long findMatchingProj();
 
     /**
@@ -501,10 +516,12 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
      */
     long srsid() const;
 
+    // TODO QGIS 4: remove unless really necessary - let's use EPSG codes instead
+
     /**
      * Returns PostGIS SRID for the CRS.
      * \returns the PostGIS spatial_ref_sys identifier for this CRS (defaults to 0)
-     */    // TODO QGIS 3: remove unless really necessary - let's use EPSG codes instead
+     */
     long postgisSrid() const;
 
     /**
